@@ -1,10 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__author__ = "Gregory Sitnin <g.sitnin@wwpass.com>"
+__author__ = "Gregory Sitnin <sitnin@gmail.com>"
 __copyright__ = "Gregory Sitnin, 2011"
 
+version = "0.2.4"
+
+
 import decorators
 import tpl_funcs
 
+
 UUID = r"[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
